// Load the dataset
d3.csv(
  'https://gist.githubusercontent.com/SirishaManthena/1c43c8e7888c5df109d46a4403734ba6/raw/d86330c694f6cf146073b47d448c19c57ed265f9/dominos.csv',
).then(function (data) {
  // Parse dates and numeric values
  var parseDate = d3.timeParse('%m/%d/%Y');
  data.forEach(function (d) {
    d.Date = parseDate(d.Date);
    d.Close = +d.Close;
  });

  // Set up SVG dimensions
  var margin = { top: 20, right: 30, bottom: 30, left: 50 },
    width = 800 - margin.left - margin.right,
    height = 400 - margin.top - margin.bottom;

  // Append SVG
  var svg = d3
    .select('body')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      'translate(' + margin.left + ',' + margin.top + ')',
    );

  // Define scales
  var x = d3.scaleTime().range([0, width]);
  var y = d3.scaleLinear().range([height, 0]);

  // Set domains
  x.domain(
    d3.extent(data, function (d) {
      return d.Date;
    }),
  );
  y.domain([
    0,
    d3.max(data, function (d) {
      return d.Close;
    }),
  ]);

  // Define the line
  var line = d3
    .line()
    .x(function (d) {
      return x(d.Date);
    })
    .y(function (d) {
      return y(d.Close);
    });

  // Add grid lines
  svg
    .append('g')
    .attr('class', 'grid')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(x).tickSize(-height).tickFormat(''))
    .selectAll('.tick')
    .attr('opacity', 0.3);

  svg
    .append('g')
    .attr('class', 'grid')
    .call(d3.axisLeft(y).tickSize(-width).tickFormat(''))
    .selectAll('.tick')
    .attr('opacity', 0.3);

  // Add the line
  svg
    .append('path')
    .data([data])
    .attr('class', 'line')
    .attr('d', line);

  // Add x-axis
  svg
    .append('g')
    .attr('class', 'x-axis')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(x));

  // Add y-axis
  svg
    .append('g')
    .attr('class', 'y-axis')
    .call(d3.axisLeft(y));

  // Add x-axis label
  svg
    .append('text')
    .attr(
      'transform',
      'translate(' +
        width / 2 +
        ' ,' +
        (height + margin.top + 20) +
        ')',
    )
    .style('text-anchor', 'middle')
    .text('Date');

  // Add y-axis label
  svg
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', 0 - margin.left)
    .attr('x', 0 - height / 2)
    .attr('dy', '1em')
    .style('text-anchor', 'middle')
    .text('Close Price');
});
